@@ -90,6 +90,7 @@ KNOWN_EXTENSIONS = (
     'flavors',
     'l3-ha',
     'l3_agent_scheduler',
+    'logging',
     'metering',
     'multi-provider',
     'net-mtu',
@@ -111,6 +112,7 @@ KNOWN_EXTENSIONS = (
     'standard-attr-revisions',
     'standard-attr-timestamp',
     'subnet_allocation',
+    'subnet_onboard',
     'tag',
     'trunk',
     'trunk-details',
